%% Scattering coefficients for the Helmholtz equation
% We compute the scattering coefficients.
% Here we assume the inclusion is a circular disk so that we can compare
% the numerical solution with the exact analytical one.
% But it is applicable for general shaped inclusions. 

clear all;
close all;
clc;



%% Make an inclusion (a circular disk as an example)
r = 1; 
nbPoints = 700; 
theta = 2*pi*(0:nbPoints-1)/nbPoints;
D=ellipse(r,r,0,0,nbPoints); 


%% Set frequency and material parameters
omega=2;
eps_m = 1; eps_c = 1;
mu_m = 1; mu_c = 5;
k_m=omega*sqrt(eps_m*mu_m);
k_c=omega*sqrt(eps_c*mu_c);

%% Compute scattering coefficients Numerically
% We compute W_jj from j=1 to j=7 numerically

N_W=7;
Wnn_num = zeros(N_W,1);
for j=1:N_W
    Wnn_num(j) = SCoeff(mu_m,mu_c,k_m,k_c,D,j,j);
end


%% Compute scattering coefficients Theoretically
% We compute W_jj from j=1 to j=7 using an analytic formula

Wnn_theo = zeros(N_W,1);
for n=1:N_W

Jm = besselj(n,k_m*r);
Jm_deri = 1/2*(besselj(n-1, k_m*r) - besselj(n+1, k_m*r));
Jc = besselj(n,k_c*r);
Jc_deri = 1/2*(besselj(n-1, k_c*r) - besselj(n+1, k_c*r));
H = besselh(n,1,k_m*r);
H_deri = 1/2*(besselh(n-1,1, k_m*r) - besselh(n+1,1, k_m*r));
det = -k_m/mu_m*Jc*H_deri + k_c/mu_c*H*Jc_deri;
a=1/det*(-k_c/mu_c*Jm*Jc_deri + k_m/mu_m*Jc*Jm_deri);


Wnn_theo(n) = 4*1i*a;
end

%% Print Output

fprintf('\n Scattering Coefficients W_{nn} for a unit disk \n-------------------------------------\n      In theory     |    Numerically');
[Wnn_num Wnn_theo]




